Index: /trunk/src/VBox/Devices/Audio/DrvAudio.cpp
===================================================================
--- /trunk/src/VBox/Devices/Audio/DrvAudio.cpp	(revision 54941)
+++ /trunk/src/VBox/Devices/Audio/DrvAudio.cpp	(revision 54942)
@@ -1482,17 +1482,19 @@
 
 static DECLCALLBACK(int) drvAudioEnableOut(PPDMIAUDIOCONNECTOR pInterface,
-                                           PPDMAUDIOGSTSTRMOUT pGstVoiceOut, bool fEnable)
+                                           PPDMAUDIOGSTSTRMOUT pGstStrmOut, bool fEnable)
 {
     AssertPtrReturn(pInterface, VERR_INVALID_POINTER);
     /* pGstVoiceOut is optional. */
 
     PDRVAUDIO pThis = PDMIAUDIOCONNECTOR_2_DRVAUDIO(pInterface);
 
-    if (pGstVoiceOut)
-    {
-        PPDMAUDIOHSTSTRMOUT pHstStrmOut = pGstVoiceOut->pHstStrmOut;
+    if (pGstStrmOut)
+    {
+        PPDMAUDIOHSTSTRMOUT pHstStrmOut = pGstStrmOut->pHstStrmOut;
         AssertPtr(pHstStrmOut);
 
-        if (pGstVoiceOut->State.fActive != fEnable)
+        LogFlowFunc(("%s: fEnable=%RTbool\n", pGstStrmOut->MixBuf.pszName, fEnable));
+
+        if (pGstStrmOut->State.fActive != fEnable)
         {
             if (fEnable)
@@ -1524,5 +1526,5 @@
             }
 
-            pGstVoiceOut->State.fActive = fEnable;
+            pGstStrmOut->State.fActive = fEnable;
         }
     }
@@ -1544,6 +1546,5 @@
         AssertPtr(pHstStrmIn);
 
-        LogFlowFunc(("%s -> %s, fEnable=%RTbool\n",
-                     pHstStrmIn->MixBuf.pszName, pGstStrmIn->MixBuf.pszName, fEnable));
+        LogFlowFunc(("%s: fEnable=%RTbool\n", pGstStrmIn->MixBuf.pszName, fEnable));
 
         if (pGstStrmIn->State.fActive != fEnable)
@@ -1482,17 +1482,19 @@
 {
     AssertPtrReturn(pInterface, VERR_INVALID_POINTER);
-    /* pGstVoiceOut is optional. */
+    /* pGstStrmOut is optional. */
 
     PDRVAUDIO pThis = PDMIAUDIOCONNECTOR_2_DRVAUDIO(pInterface);
